# armstrong-checker

A Python library to check if a number is an Armstrong number.

## Usage
    
    from armstrong_checker import armstrong

    armstrong("153")

    or

    armstrong(153)



## Explanations

* The function armstrong() receives either a string or an integer containing a number.
* This number must be an integer.
* If any other parameter is passed, the function will return an error.
* The return value of this function is a Boolean.


## Tested Limit
The highest Armstrong number tested was:

**115132219018763992565095597973971522401**

So, I guarantee it will work with any number below that😃😜.

## License
This project is licensed under the MIT License.


## Instalation

```bash
pip install armstrong-checker